@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
-from django.db.models import Q
+import copy
 from functools import wraps
 import json
 import sys
-from cms.toolbar_pool import toolbar_pool
-from cms.constants import PAGE_TYPES_ID, PUBLISHER_STATE_PENDING
 
 import django
 from django.contrib.admin.helpers import AdminForm
@@ -17,6 +15,7 @@ from django.contrib.contenttypes.models import ContentType
 from django.contrib.sites.models import Site, get_current_site
 from django.core.exceptions import PermissionDenied, ObjectDoesNotExist, ValidationError
 from django.db import router
+from django.db.models import Q
 from django.http import HttpResponseRedirect, HttpResponse, Http404, HttpResponseBadRequest, HttpResponseForbidden
 from django.shortcuts import render_to_response, get_object_or_404
 from django.template.context import RequestContext
@@ -25,28 +24,30 @@ from django.utils.translation import ugettext_lazy as _, get_language
 from django.utils.decorators import method_decorator
 from django.views.decorators.http import require_POST
 
-from cms.admin.placeholderadmin import PlaceholderAdminMixin
-from cms.plugin_pool import plugin_pool
-from cms.utils.conf import get_cms_setting
-from cms.utils.compat.dj import force_unicode, is_installed
-from cms.utils.compat.urls import unquote
-from cms.utils.helpers import find_placeholder_relation
-from cms.utils.urlutils import add_url_parameters, admin_reverse
 from cms.admin.change_list import CMSChangeList
 from cms.admin.dialog.views import get_copy_dialog
 from cms.admin.forms import (PageForm, AdvancedSettingsForm, PagePermissionForm,
                              PublicationDatesForm)
 from cms.admin.permissionadmin import (PERMISSION_ADMIN_INLINES, PagePermissionInlineAdmin, ViewRestrictionInlineAdmin)
+from cms.admin.placeholderadmin import PlaceholderAdminMixin
 from cms.admin.views import revert_plugins
+from cms.constants import PAGE_TYPES_ID, PUBLISHER_STATE_PENDING
 from cms.models import Page, Title, CMSPlugin, PagePermission, GlobalPagePermission, StaticPlaceholder
 from cms.models.managers import PagePermissionsPermissionManager
+from cms.plugin_pool import plugin_pool
+from cms.toolbar_pool import toolbar_pool
 from cms.utils import helpers, permissions, get_language_from_request, admin as admin_utils, copy_plugins
 from cms.utils.i18n import get_language_list, get_language_tuple, get_language_object, force_language
 from cms.utils.admin import jsonify_request
+from cms.utils.compat.dj import force_unicode, is_installed
+from cms.utils.compat.urls import unquote
+from cms.utils.conf import get_cms_setting
+from cms.utils.helpers import find_placeholder_relation
 from cms.utils.permissions import has_global_page_permission, has_generic_permission
 from cms.utils.plugins import current_site
 from cms.utils.compat import DJANGO_1_4
 from cms.utils.transaction import wrap_transaction
+from cms.utils.urlutils import add_url_parameters, admin_reverse
 
 require_POST = method_decorator(require_POST)
 
@@ -176,7 +177,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
         target = request.GET.get('target', None)
         position = request.GET.get('position', None)
 
-        if 'recover' in request.path:
+        if 'recover' in request.path_info:
             pk = obj.pk
             if obj.parent_id:
                 parent = Page.objects.get(pk=obj.parent_id)
@@ -192,7 +193,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
             obj.save(no_signals=True)
 
         else:
-            if 'history' in request.path:
+            if 'history' in request.path_info:
                 old_obj = Page.objects.get(pk=obj.pk)
                 obj.level = old_obj.level
                 obj.parent_id = old_obj.parent_id
@@ -204,7 +205,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
             new = True
         obj.save()
 
-        if 'recover' in request.path or 'history' in request.path:
+        if 'recover' in request.path_info or 'history' in request.path_info:
             revert_plugins(request, obj.version.pk, obj)
 
         if target is not None and position is not None:
@@ -227,7 +228,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
             obj.save()
             for lang in copy_target.languages.split(','):
                 copy_target._copy_contents(obj, lang)
-        if not 'permission' in request.path:
+        if not 'permission' in request.path_info:
             language = form.cleaned_data['language']
             Title.objects.set_or_create(
                 request,
@@ -248,16 +249,16 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
             return form.fieldsets
 
     def get_inline_classes(self, request, obj=None, **kwargs):
-        if obj and 'permission' in request.path:
+        if obj and 'permission' in request.path_info:
             return PERMISSION_ADMIN_INLINES
         return []
 
     def get_form_class(self, request, obj=None, **kwargs):
-        if 'advanced' in request.path:
+        if 'advanced' in request.path_info:
             return AdvancedSettingsForm
-        elif 'permission' in request.path:
+        elif 'permission' in request.path_info:
             return PagePermissionForm
-        elif 'dates' in request.path:
+        elif 'dates' in request.path_info:
             return PublicationDatesForm
         return self.form
 
@@ -269,6 +270,11 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
         language = get_language_from_request(request, obj)
         form_cls = self.get_form_class(request, obj)
         form = super(PageAdmin, self).get_form(request, obj, form=form_cls, **kwargs)
+        # get_form method operates by overriding initial fields value which
+        # may persist across invocation. Code below deepcopies fields definition
+        # to avoid leaks
+        for field in form.base_fields.keys():
+            form.base_fields[field] = copy.deepcopy(form.base_fields[field])
 
         if 'language' in form.base_fields:
             form.base_fields['language'].initial = language
@@ -287,8 +293,8 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
         self.inlines = self.get_inline_classes(request, obj, **kwargs)
 
         if obj:
-            if 'history' in request.path or 'recover' in request.path:
-                version_id = request.path.split('/')[-2]
+            if 'history' in request.path_info or 'recover' in request.path_info:
+                version_id = request.path_info.split('/')[-2]
             else:
                 version_id = None
 
@@ -437,7 +443,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
             self._current_page = obj
         response = super(PageAdmin, self).change_view(
             request, object_id, form_url=form_url, extra_context=extra_context)
-        if tab_language and response.status_code == 302 and response._headers['location'][1] == request.path:
+        if tab_language and response.status_code == 302 and response._headers['location'][1] == request.path_info:
             location = response._headers['location']
             response._headers['location'] = (location[0], "%s?language=%s" % (location[1], tab_language))
         return response
@@ -681,7 +687,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
             # is screwed up with the database, so display an error page.
             if ERROR_FLAG in request.GET.keys():
                 return render_to_response('admin/invalid_setup.html', {'title': _('Database error')})
-            return HttpResponseRedirect(request.path + '?' + ERROR_FLAG + '=1')
+            return HttpResponseRedirect(request.path_info + '?' + ERROR_FLAG + '=1')
         cl.set_items(request)
 
         site_id = request.GET.get('site__exact', None)
