@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from functools import update_wrapper
+from cms.utils.urlutils import admin_reverse
 from django.http import HttpResponseRedirect, HttpResponse
 from django.contrib.auth.admin import csrf_protect_m
 from django.contrib.admin import ModelAdmin
@@ -7,7 +8,6 @@ from django.contrib.admin import ModelAdmin
 from django.contrib import admin
 
 from cms.models import UserSettings
-from django.core.urlresolvers import reverse
 import json
 from cms.utils.transaction import wrap_transaction
 
@@ -65,7 +65,7 @@ class SettingsAdmin(ModelAdmin):
         obj.save()
 
     def response_post_save_change(self, request, obj):
-        post_url = reverse('admin:index', current_app=self.admin_site.name)
+        post_url = admin_reverse('index', current_app=self.admin_site.name)
         return HttpResponseRedirect(post_url)
 
     def has_change_permission(self, request, obj=None):
