@@ -200,9 +200,10 @@ class TitleManager(PublisherManager):
                 value = cleaned_data.get(name, None)
                 setattr(obj, name, value)
         if page.has_advanced_settings_permission(request):
-            overwrite_url = cleaned_data.get('overwrite_url', None)
-            obj.has_url_overwrite = bool(overwrite_url)
-            obj.path = overwrite_url
+            if 'overwrite_url' in cleaned_data:
+                overwrite_url = cleaned_data.get('overwrite_url', None)
+                obj.has_url_overwrite = bool(overwrite_url)
+                obj.path = overwrite_url
             for field in advanced_fields:
                 if field in form.base_fields:
                     value = cleaned_data.get(field, None)
