@@ -1,4 +1,5 @@
 from cms.apphook_pool import apphook_pool
+from cms.utils.compat.dj import is_installed
 from cms.views import details
 from django.conf import settings
 from django.conf.urls import url, patterns, include
@@ -24,7 +25,7 @@ if apphook_pool.get_apphooks():
 urlpatterns = patterns('', *urlpatterns)
 
 
-if settings.DEBUG and 'debug_toolbar' in settings.INSTALLED_APPS:
+if settings.DEBUG and is_installed('debug_toolbar'):
     import debug_toolbar
     urlpatterns += patterns('',
         url(r'^__debug__/', include(debug_toolbar.urls)),
