@@ -4,15 +4,19 @@ import sys
 
 from django.core.urlresolvers import clear_url_caches, reverse
 from django.utils import six
+from django.utils.timezone import now
 
 from cms.api import create_page, create_title
 from cms.app_base import CMSApp
 from cms.apphook_pool import apphook_pool
 from cms.appresolver import applications_page_check, clear_app_resolvers, get_app_patterns
+from cms.cms_toolbar import PlaceholderToolbar
 from cms.models import Title
+from cms.test_utils.project.placeholderapp.models import Example1
 from cms.test_utils.testcases import CMSTestCase, SettingsOverrideTestCase
 from cms.test_utils.util.context_managers import SettingsOverride
 from cms.tests.menu_utils import DumbPageLanguageUrl
+from cms.toolbar.toolbar import CMSToolbar
 from cms.utils.compat.dj import get_user_model
 from cms.utils.conf import get_cms_setting
 from cms.utils.i18n import force_language
@@ -497,6 +501,77 @@ class ApphooksTestCase(CMSTestCase):
             name = "Test App 2"
         self.assertIsNotNone(TestApp2)
 
+    def test_toolbar_current_app_namespace(self):
+        with SettingsOverride(ROOT_URLCONF='cms.test_utils.project.second_urls_for_apphook_tests'):
+            en_title = self.create_base_structure(NS_APP_NAME, 'en', 'instance_ns')  # nopyflakes
+            with force_language("en"):
+                path = reverse('namespaced_app_ns:sample-settings')
+            request = self.get_request(path)
+            toolbar = CMSToolbar(request)
+            self.assertTrue(toolbar.toolbars['cms.test_utils.project.sampleapp.cms_toolbar.CategoryToolbar'].is_current_app)
+            self.assertFalse(toolbar.toolbars['cms.test_utils.project.extensionapp.cms_toolbar.MyTitleExtensionToolbar'].is_current_app)
+
+            # Testing a decorated view
+            with force_language("en"):
+                path = reverse('namespaced_app_ns:sample-exempt')
+            request = self.get_request(path)
+            toolbar = CMSToolbar(request)
+            self.assertTrue(toolbar.toolbars['cms.test_utils.project.sampleapp.cms_toolbar.CategoryToolbar'].is_current_app)
+            self.assertFalse(toolbar.toolbars['cms.test_utils.project.extensionapp.cms_toolbar.MyTitleExtensionToolbar'].is_current_app)
+
+    def test_toolbar_current_app_apphook_with_implicit_current_app(self):
+        with SettingsOverride(ROOT_URLCONF='cms.test_utils.project.second_urls_for_apphook_tests'):
+            en_title = self.create_base_structure(NS_APP_NAME, 'en', 'namespaced_app_ns')  # nopyflakes
+            with force_language("en"):
+                path = reverse('namespaced_app_ns:current-app')
+            request = self.get_request(path)
+            toolbar = CMSToolbar(request)
+            self.assertTrue(toolbar.toolbars['cms.test_utils.project.sampleapp.cms_toolbar.CategoryToolbar'].is_current_app)
+            self.assertFalse(toolbar.toolbars['cms.test_utils.project.extensionapp.cms_toolbar.MyTitleExtensionToolbar'].is_current_app)
+
+    def test_toolbar_no_namespace(self):
+        # Test with a basic application with no defined app_name and no namespace
+        with SettingsOverride(ROOT_URLCONF='cms.test_utils.project.placeholderapp_urls'):
+            self.create_base_structure(APP_NAME, 'en')
+            path = reverse('detail', kwargs={'id': 20})
+            request = self.get_request(path)
+            toolbar = CMSToolbar(request)
+            self.assertFalse(toolbar.toolbars['cms.test_utils.project.sampleapp.cms_toolbar.CategoryToolbar'].is_current_app)
+            self.assertFalse(toolbar.toolbars['cms.test_utils.project.extensionapp.cms_toolbar.MyTitleExtensionToolbar'].is_current_app)
+            self.assertTrue(toolbar.toolbars['cms.test_utils.project.placeholderapp.cms_toolbar.Example1Toolbar'].is_current_app)
+
+    def test_toolbar_staff(self):
+        # Test that the toolbar contains edito mode switcher if placeholders are available
+        apphooks = (
+            'cms.test_utils.project.placeholderapp.cms_app.Example1App',
+        )
+        with SettingsOverride(CMS_APPHOOKS=apphooks, ROOT_URLCONF='cms.test_utils.project.placeholderapp_urls'):
+            self.create_base_structure('Example1App', 'en')
+            ex1 = Example1.objects.create(char_1='1', char_2='2', char_3='3', char_4='4', date_field=now())
+            path = reverse('example_detail', kwargs={'pk': ex1.pk})
+
+            self.user = self._create_user('admin_staff', True, True)
+            response = self.client.get(path+"?edit")
+            toolbar = CMSToolbar(response.context['request'])
+            toolbar.populate()
+            placeholder_toolbar = PlaceholderToolbar(response.context['request'], toolbar, True, path)
+            placeholder_toolbar.populate()
+            placeholder_toolbar.init_placeholders_from_request()
+            placeholder_toolbar.add_structure_mode()
+            self.assertEqual(len(placeholder_toolbar.toolbar.get_right_items()), 1)
+
+            self.user = self._create_user('staff', True, False)
+            response = self.client.get(path+"?edit")
+            toolbar = CMSToolbar(response.context['request'])
+            toolbar.populate()
+            placeholder_toolbar = PlaceholderToolbar(response.context['request'], toolbar, True, path)
+            placeholder_toolbar.populate()
+            placeholder_toolbar.init_placeholders_from_request()
+            placeholder_toolbar.add_structure_mode()
+            self.assertEqual(len(placeholder_toolbar.toolbar.get_right_items()), 1)
+
+            self.user = None
+
 
 class ApphooksPageLanguageUrlTestCase(SettingsOverrideTestCase):
     settings_overrides = {'ROOT_URLCONF': 'cms.test_utils.project.second_urls_for_apphook_tests'}
