@@ -7,7 +7,7 @@ from django.utils import translation
 from django.utils.translation import ugettext_lazy as _
 
 from cms.exceptions import LanguageError
-from cms.utils.conf import get_cms_setting
+from cms.utils.conf import get_cms_setting, get_site_id
 
 
 @contextmanager
@@ -20,7 +20,7 @@ def force_language(new_lang):
 
 
 def get_languages(site_id=None):
-    site_id = get_site(site_id)
+    site_id = get_site_id(site_id)
     result = get_cms_setting('LANGUAGES').get(site_id)
     if not result:
         result = []
@@ -33,19 +33,6 @@ def get_languages(site_id=None):
     return result
 
 
-def get_languages_for_user(user):
-    if user and user.is_staff:
-        languages = get_language_list()
-    else:
-        languages = get_public_languages()
-    return languages
-
-
-def get_languages_for_page_user(page, user=None):
-    page_languages = page.get_languages()
-    return [language for language in get_languages_for_user(user) if language in page_languages]
-
-
 def get_language_code(language_code):
     """
     Returns language code while making sure it's in LANGUAGES
@@ -74,16 +61,6 @@ def get_current_language():
     return get_language_code(language_code)
 
 
-def get_site(site):
-    if site is None:
-        return settings.SITE_ID
-    else:
-        try:
-            return int(site)
-        except TypeError:
-            return site.pk
-
-
 def get_language_list(site_id=None):
     """
     :return: returns a list of iso2codes for this site
@@ -175,7 +152,10 @@ def get_fallback_languages(language, site_id=None):
     """
     returns a list of fallback languages for the given language
     """
-    language = get_language_object(language, site_id)
+    try:
+        language = get_language_object(language, site_id)
+    except LanguageError:
+        language = get_languages(site_id)[0]
     return language.get('fallbacks', [])
 
 
