@@ -4,24 +4,27 @@ from django.db.models import Q
 import re
 
 APPEND_TO_SLUG = "-copy"
-COPY_SLUG_REGEX = re.compile(r'^.*-copy(?:-(\d)*)?$')
+COPY_SLUG_REGEX = re.compile(r'^.*-copy(?:-(\d+)*)?$')
+
 
 def is_valid_page_slug(page, parent, lang, slug, site, path=None):
     """Validates given slug depending on settings.
     """
     from cms.models import Title
-    # Exclude the page with the publisher_state == page.PUBLISHER_STATE_DELETE
-    qs = Title.objects.filter(page__site=site).exclude(
-        Q(page=page) |
-        Q(page=page.publisher_public) |
-        Q(page__publisher_state=page.PUBLISHER_STATE_DELETE)
-    )
+    # Since 3.0 this must take into account unpublished pages as it's necessary
+    # to be able to open every page to edit content.
+    # If page is newly created (i.e. page.pk is None) we skip filtering out
+    # titles attached to the same page
+    if page.pk:
+        qs = Title.objects.filter(page__site=site).exclude(page=page)
+    else:
+        qs = Title.objects.filter(page__site=site)
 
     if settings.USE_I18N:
         qs = qs.filter(language=lang)
 
     if parent:
-        if parent.is_home():
+        if parent.is_home:
             qs = qs.filter(Q(page__parent=parent) |
                            Q(page__parent__isnull=True))
         else:
@@ -32,10 +35,10 @@ def is_valid_page_slug(page, parent, lang, slug, site, path=None):
     if page.pk:
         qs = qs.exclude(Q(language=lang) & Q(page=page))
         qs = qs.exclude(page__publisher_public=page)
-        ## Check for slugs
+        # Check for slugs
     if qs.filter(slug=slug).count():
         return False
-        ## Check for path
+        # Check for path
     if path and qs.filter(path=path).count():
         return False
     return True
@@ -49,7 +52,6 @@ def get_available_slug(title, new_slug=None):
 
     Returns: slug
     """
-    rewrite_slug = False
     slug = new_slug or title.slug
     # We need the full path for the title to check for conflicting urls
     title.slug = slug
@@ -63,11 +65,10 @@ def get_available_slug(title, new_slug=None):
         match = COPY_SLUG_REGEX.match(slug)
         if match:
             try:
-                next = int(match.groups()[0]) + 1
-                slug = "-".join(slug.split('-')[:-1]) + "-%d" % next
+                next_id = int(match.groups()[0]) + 1
+                slug = "-".join(slug.split('-')[:-1]) + "-%d" % next_id
             except TypeError:
                 slug += "-2"
-
         else:
             slug += APPEND_TO_SLUG
         return get_available_slug(title, slug)
@@ -80,7 +81,7 @@ def check_title_slugs(page):
     cut/paste.
     """
     for title in page.title_set.all():
-        old_slug = title.slug
+        old_slug, old_path = title.slug, title.path
         title.slug = get_available_slug(title)
-        if title.slug != old_slug:
+        if title.slug != old_slug or title.path != old_path:
             title.save()
